==> zbxe.beta.0.2.4.tgz: zbxe/common/lang/en.lang.php <==
<?php
    /**
     * @file   common/lang/en.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  English Language Pack (Only basic words are included here)
     **/

    // words for action, which is basically used
    $lang->cmd_write = 'Write';
    $lang->cmd_reply = 'Reply';
    $lang->cmd_delete = 'Delete';
    $lang->cmd_modify = 'Modify';
    $lang->cmd_edit = 'Edit';
    $lang->cmd_view = 'View';
    $lang->cmd_view_all = 'View All';
    $lang->cmd_list = 'List';
    $lang->cmd_prev = 'Prev';
    $lang->cmd_next = 'Next';
    $lang->cmd_send_trackback = 'Send Trackback';
    $lang->cmd_registration = $lang->cmd_submit = 'Submit';
    $lang->cmd_comment_registration = 'Add Comment';
    $lang->cmd_insert = 'Insert';
    $lang->cmd_save = 'Save';
    $lang->cmd_load = 'Load';
    $lang->cmd_input = 'Input';
    $lang->cmd_search = 'Search';
    $lang->cmd_cancel = 'Cancel';
    $lang->cmd_back = 'Go Back';
    $lang->cmd_vote = 'Recommend';
    $lang->cmd_vote_down = 'Criticize';
    $lang->cmd_declare = 'Accuse';
    $lang->cmd_declared_list = 'Accusations List';
    $lang->cmd_copy = 'Copy';
    $lang->cmd_move = 'Move';
    $lang->cmd_move_up = 'Up';
    $lang->cmd_move_down = 'Down';
    $lang->cmd_add_indent = 'Indent';
    $lang->cmd_remove_indent = 'Outdent';
    $lang->cmd_management = 'Manage';
    $lang->cmd_make = 'Create';
    $lang->cmd_select = 'Select';
    $lang->cmd_select_all = 'Select All';
    $lang->cmd_unselect_all = 'Deselect All';
    $lang->cmd_reverse_all = 'Reverse';
    $lang->cmd_close_all = 'Close All';
    $lang->cmd_open_all = 'Open All';
    $lang->cmd_reload = 'Reload';
    $lang->cmd_close = 'Close';
    $lang->cmd_open = 'Open';
    $lang->cmd_setup = 'Configure';
    $lang->cmd_addition_setup = 'Additional Setup';
	$lang->cmd_option = 'Option';
    $lang->cmd_apply = 'Apply';
    $lang->cmd_open_calendar = 'Select a Date';
    $lang->cmd_send = 'Send';
    $lang->cmd_print = 'Print';
    $lang->cmd_scrap = 'Scrap';
    $lang->cmd_preview = 'Preview';
    $lang->cmd_reset = 'Reset';
    $lang->cmd_remake_cache = "Re-create cache file";
    $lang->cmd_publish = "Publish";

    $lang->enable = 'Enable';
    $lang->disable = 'Disable';

    // Essential Words
    $lang->no = 'No.';
    $lang->notice = 'Notice';
    $lang->secret = 'Secret';
    $lang->category = 'Category';
    $lang->document_srl = 'Doc. No.';
    $lang->user_id = 'User ID';
    $lang->author = 'Developer';
    $lang->password = 'Password';
    $lang->password1 = 'Password';
    $lang->password2 = 'Confirm Password';
    $lang->admin_id = 'Admin ID';
    $lang->writer = 'Author';
    $lang->user_name = 'User Name';
    $lang->nick_name = 'Nick Name';
    $lang->email_address = 'Email';
    $lang->homepage = 'Homepage';
    $lang->blog = 'Blog';
    $lang->birthday = 'Birthdate';
    $lang->browser_title = 'Browser Title';
    $lang->title = 'Subject';
    $lang->title_content = 'Subject+Content';
    $lang->topic = 'Topic';
    $lang->replies = 'Reply';
    $lang->content = 'Content';
    $lang->document = 'Article';
    $lang->comment = 'Comment';
    $lang->description = 'Description';
    $lang->trackback = 'Trackback';
    $lang->tag = 'Tag';
    $lang->allow_comment = 'Allow Comments';
    $lang->lock_comment = 'Block Comments';
    $lang->allow_trackback = 'Allow Trackbacks';
    $lang->uploaded_file = 'Attachment';
    $lang->grant = 'Permission';
    $lang->target = 'Target';
    $lang->total = 'Total';
    $lang->total_count = 'Count Total';
    $lang->ipaddress = 'IP Address';
    $lang->path = 'Path';
    $lang->cart = 'Selected Item';
    $lang->friend = 'Friends';
    $lang->notify = 'Notification';

    $lang->mid = 'Module Name';
    $lang->layout = 'Layout';
    $lang->widget = 'Widget';
    $lang->module = 'Module';
    $lang->skin = 'Theme';
    $lang->colorset = 'Colorset';
    $lang->extra_vars = 'Extra Vars';

    $lang->document_url = 'Article URL';
    $lang->trackback_url = 'Trackback URL';
    $lang->blog_name = 'Blog Title';
    $lang->excerpt = 'Quotation';

    $lang->document_count = 'Total Articles';
    $lang->page_count = 'Page Count';
    $lang->list_count = 'List Count';
    $lang->readed_count = 'Hits';
    $lang->voted_count = 'Votes';
    $lang->member_count = 'Member Count';
    $lang->date = 'Date';
    $lang->regdate = 'Registered Date';
    $lang->last_update = 'Late Update';
    $lang->last_post = 'Late Post';
    $lang->signup_date = 'Registered Date';
    $lang->last_login = 'Late Login';
    $lang->first_page = 'First Page';
    $lang->last_page = 'Last Page';
    $lang->search_target = 'Searching Target';
    $lang->search_keyword = 'Searching Keyword';
    $lang->is_default = 'Default';

    $lang->no_documents = 'No Articles';

    $lang->board_manager = 'Board Settings';
    $lang->member_manager = 'Member Settings';
    $lang->layout_manager = 'Layout Settings';

    $lang->use = 'Use';
    $lang->notuse = 'Not use';
    $lang->not_exists = "Does not exist";

    $lang->unit_sec = 'sec';
    $lang->unit_min = 'min';
    $lang->unit_hour = 'hr';
    $lang->unit_day = 'th';
    $lang->unit_week = 'week';
    $lang->unit_month = 'month';
    $lang->unit_year = 'year';

    // Descriptions
    $lang->about_tag = 'You can submit multiple tags by inserting commas(,) between each tag';
    $lang->about_layout = 'Layouts decorate the appearance of your modules. you can configure them from Layout menu on the top';

    // Messages
    $lang->msg_call_server = 'Requesting to the server, please wait';
    $lang->msg_db_not_setted = 'DB configuration has not been set';
    $lang->msg_invalid_queryid = 'Specified query ID value is invalid';
    $lang->msg_not_permitted = 'You do not have permission to access';
    $lang->msg_input_password = 'Please enter your password';
    $lang->msg_invalid_document = 'Invalid Article Number';
    $lang->msg_invalid_request = 'Invalid Request';
    $lang->msg_invalid_password = 'Invalid Password';
    $lang->msg_error_occured = 'Error has occured';
    $lang->msg_not_founded = 'Target could not be found';
    $lang->msg_no_result = 'Nothing found';

    $lang->msg_not_permitted_act = 'You do not have permission to execute requested action';
    $lang->msg_module_is_not_exists = 'Requested module could not be found';
    $lang->msg_module_is_not_standalone = 'Requested module cannot be executed independently';

    $lang->success_registed = 'Registered successfully';
    $lang->success_declared = 'Accused successfully';
    $lang->success_updated = 'Updated successfully';
    $lang->success_deleted = 'Deleted successfully';
    $lang->success_voted = 'Recommended successfully';
    $lang->success_moved = 'Moved successfully';
    $lang->success_sended = 'Sent successfully';
    $lang->success_reset = 'Reset successfully';
    $lang->success_leaved = 'All member data have been deleted completely.';
    $lang->success_saved = 'Saved successfully';

    $lang->fail_to_delete = 'Could not be deleted';
    $lang->fail_to_move = 'Could not be moved';

    $lang->failed_voted = 'Could not recommend';
    $lang->failed_declared = 'Could not accuse';
    $lang->fail_to_delete_have_children = 'Please try again after removing replies first';

    $lang->confirm_submit = 'Are you sure to submit?';
    $lang->confirm_logout = 'Are you sure to logout?';
    $lang->confirm_vote = 'Are you sure to recommend?';
    $lang->confirm_delete = 'Are you sure to delete?';
    $lang->confirm_move = 'Are you sure to move?';
    $lang->confirm_reset = 'Are you sure to reset?';
    $lang->confirm_leave = 'Are you sure to leave?';

    $lang->column_type = 'Column Type';
    $lang->column_type_list['text'] = 'one-line text';
    $lang->column_type_list['homepage'] = 'url';
    $lang->column_type_list['email_address'] = 'email';
    $lang->column_type_list['tel'] = 'phone number';
    $lang->column_type_list['textarea'] = 'multi-line textarea';
    $lang->column_type_list['checkbox'] = 'checkbox (multiple selection)';
    $lang->column_type_list['select'] = 'select box (single selection)';
    $lang->column_type_list['kr_zip'] = 'zip code (Korean)';
    $lang->column_type_list['date'] = 'date (yyyy/mm/dd)';
    //$lang->column_type_list['jp_zip'] = 'zip code (Japanese)';
    $lang->column_name = 'Column Name';
    $lang->column_title = 'Column Title';
    $lang->default_value = 'Default Value';
    $lang->is_active = 'Active';
    $lang->is_required = 'Required Field';

    // Alert messages for Javascript using by XML filter
    $lang->filter->isnull = 'Please input a value for %s';
    $lang->filter->outofrange = 'Please align the text length of %s';
    $lang->filter->equalto = "%s's value is invalid";
    $lang->filter->invalid_email = "%s's format is invalid. ex) zbxe@zeroboard.com";
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "%s's format is invalid.\\nAll values should consist of alphabets, numbers or underscore(_) and the first letter should be English alphabet";
    $lang->filter->invalid_homepage = "%s's format is invalid. ex) http://www.zeroboard.com";
    $lang->filter->invalid_korean = "%s's format is invalid. Please input only Korean";
    $lang->filter->invalid_korean_number = "%s's format is invalid. Please input Korean or numbers";
    $lang->filter->invalid_alpha = "%s's format is invalid. Please input only alphabets";
    $lang->filter->invalid_alpha_number = "%s's format is invalid. Please input alphabets or numbers";
    $lang->filter->invalid_number = "%s's format is invalid. Please input only numbers";
?>

==> zbxe.beta.0.2.6.tgz: zbxe/common/lang/en.lang.php <==
<?php
    /**
     * @file   common/lang/en.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  English Language Pack (Only basic words are included here)
     **/

    // words for action, which is basically used
    $lang->cmd_write = 'Write';
    $lang->cmd_reply = 'Reply';
    $lang->cmd_delete = 'Delete';
    $lang->cmd_modify = 'Modify';
    $lang->cmd_edit = 'Edit';
    $lang->cmd_view = 'View';
    $lang->cmd_view_all = 'View All';
    $lang->cmd_list = 'List';
    $lang->cmd_prev = 'Prev';
    $lang->cmd_next = 'Next';
    $lang->cmd_send_trackback = 'Send Trackback';
    $lang->cmd_registration = $lang->cmd_submit = 'Submit';
    $lang->cmd_comment_registration = 'Add Comment';
    $lang->cmd_insert = 'Insert';
    $lang->cmd_save = 'Save';
    $lang->cmd_load = 'Load';
    $lang->cmd_input = 'Input';
    $lang->cmd_search = 'Search';
    $lang->cmd_cancel = 'Cancel';
    $lang->cmd_back = 'Go Back';
    $lang->cmd_vote = 'Recommend';
    $lang->cmd_vote_down = 'Criticize';
    $lang->cmd_declare = 'Accuse';
    $lang->cmd_declared_list = 'Accusations List';
    $lang->cmd_copy = 'Copy';
    $lang->cmd_move = 'Move';
    $lang->cmd_move_up = 'Up';
    $lang->cmd_move_down = 'Down';
    $lang->cmd_add_indent = 'Indent';
    $lang->cmd_remove_indent = 'Outdent';
    $lang->cmd_management = 'Manage';
    $lang->cmd_make = 'Create';
    $lang->cmd_select = 'Select';
    $lang->cmd_select_all = 'Select All';
    $lang->cmd_unselect_all = 'Deselect All';
    $lang->cmd_reverse_all = 'Reverse';
    $lang->cmd_close_all = 'Close All';
    $lang->cmd_open_all = 'Open All';
    $lang->cmd_reload = 'Reload';
    $lang->cmd_close = 'Close';
    $lang->cmd_open = 'Open';
    $lang->cmd_setup = 'Configure';
    $lang->cmd_addition_setup = 'Additional Setup';
	$lang->cmd_option = 'Option';
    $lang->cmd_apply = 'Apply';
    $lang->cmd_open_calendar = 'Select a Date';
    $lang->cmd_send = 'Send';
    $lang->cmd_print = 'Print';
    $lang->cmd_scrap = 'Scrap';
    $lang->cmd_preview = 'Preview';
    $lang->cmd_reset = 'Reset';
    $lang->cmd_remake_cache = "Re-create cache file";
    $lang->cmd_publish = "Publish";

    $lang->enable = 'Enable';
    $lang->disable = 'Disable';

    // Essential Words
    $lang->no = 'No.';
    $lang->notice = 'Notice';
    $lang->secret = 'Secret';
    $lang->category = 'Category';
    $lang->document_srl = 'Doc. No.';
    $lang->user_id = 'User ID';
    $lang->author = 'Developer';
    $lang->password = 'Password';
    $lang->password1 = 'Password';
    $lang->password2 = 'Confirm Password';
    $lang->admin_id = 'Admin ID';
    $lang->writer = 'Author';
    $lang->user_name = 'User Name';
    $lang->nick_name = 'Nick Name';
    $lang->email_address = 'Email';
    $lang->homepage = 'Homepage';
    $lang->blog = 'Blog';
    $lang->birthday = 'Birthdate';
    $lang->browser_title = 'Browser Title';
    $lang->title = 'Subject';
    $lang->title_content = 'Subject+Content';
    $lang->topic = 'Topic';
    $lang->replies = 'Reply';
    $lang->content = 'Content';
    $lang->document = 'Article';
    $lang->comment = 'Comment';
    $lang->description = 'Description';
    $lang->trackback = 'Trackback';
    $lang->tag = 'Tag';
    $lang->allow_comment = 'Allow Comments';
    $lang->lock_comment = 'Block Comments';
    $lang->allow_trackback = 'Allow Trackbacks';
    $lang->uploaded_file = 'Attachment';
    $lang->grant = 'Permission';
    $lang->target = 'Target';
    $lang->total = 'Total';
    $lang->total_count = 'Count Total';
    $lang->ipaddress = 'IP Address';
    $lang->path = 'Path';
    $lang->cart = 'Selected Item';
    $lang->friend = 'Friends';
    $lang->notify = 'Notification';

    $lang->mid = 'Module Name';
    $lang->layout = 'Layout';
    $lang->widget = 'Widget';
    $lang->module = 'Module';
    $lang->skin = 'Theme';
    $lang->colorset = 'Colorset';
    $lang->extra_vars = 'Extra Vars';

    $lang->document_url = 'Article URL';
    $lang->trackback_url = 'Trackback URL';
    $lang->blog_name = 'Blog Title';
    $lang->excerpt = 'Quotation';

    $lang->document_count = 'Total Articles';
    $lang->page_count = 'Page Count';
    $lang->list_count = 'List Count';
    $lang->readed_count = 'Views';
    $lang->voted_count = 'Votes';
    $lang->member_count = 'Member Count';
    $lang->date = 'Date';
    $lang->regdate = 'Registered Date';
    $lang->last_update = 'Last Update';
    $lang->last_post = 'Last Post';
    $lang->signup_date = 'Join Date';
    $lang->last_login = 'Last Login';
    $lang->first_page = 'First Page';
    $lang->last_page = 'Last Page';
    $lang->search_target = 'Searching Target';
    $lang->search_keyword = 'Searching Keyword';
    $lang->is_default = 'Default';

    $lang->no_documents = 'No Articles';

    $lang->board_manager = 'Board Settings';
    $lang->member_manager = 'Member Settings';
    $lang->layout_manager = 'Layout Settings';

    $lang->use = 'Use';
    $lang->notuse = 'Not use';
    $lang->not_exists = "Does not exist";

    $lang->unit_sec = 'sec';
    $lang->unit_min = 'min';
    $lang->unit_hour = 'hr';
    $lang->unit_day = 'th';
    $lang->unit_week = 'week';
    $lang->unit_month = 'month';
    $lang->unit_year = 'year';

    // Descriptions
    $lang->about_tag = 'You may submit multiple tags by inserting commas(,) between each tag';
    $lang->about_layout = 'Layouts decorate the appearance of your modules. you can configure them from Layout menu on the top';

    // Messages
    $lang->msg_call_server = 'Requesting to the server, please wait';
    $lang->msg_db_not_setted = 'DB configuration has not been set';
    $lang->msg_invalid_queryid = 'Specified query ID value is invalid';
    $lang->msg_not_permitted = 'You do not have permission to access';
    $lang->msg_input_password = 'Please input the password';
    $lang->msg_invalid_document = 'Invalid Article Number';
    $lang->msg_invalid_request = 'Invalid Request';
    $lang->msg_invalid_password = 'Invalid Password';
    $lang->msg_error_occured = 'Error has occured';
    $lang->msg_not_founded = 'Target could not be found';
    $lang->msg_no_result = 'Nothing found';

    $lang->msg_not_permitted_act = 'You do not have permission to execute requested action';
    $lang->msg_module_is_not_exists = 'Requested module could not be found';
    $lang->msg_module_is_not_standalone = 'Requested module cannot be executed independently';

    $lang->success_registed = 'Registered successfully';
    $lang->success_declared = 'Accused successfully';
    $lang->success_updated = 'Updated successfully';
    $lang->success_deleted = 'Deleted successfully';
    $lang->success_voted = 'Recommended successfully';
    $lang->success_moved = 'Moved successfully';
    $lang->success_sended = 'Sent successfully';
    $lang->success_reset = 'Reset successfully';
    $lang->success_leaved = 'All member data have been deleted completely.';
    $lang->success_saved = 'Saved successfully';

    $lang->fail_to_delete = 'Could not be deleted';
    $lang->fail_to_move = 'Could not be moved';

    $lang->failed_voted = 'Could not recommend';
    $lang->failed_declared = 'Could not accuse';
    $lang->fail_to_delete_have_children = 'Please try again after removing replies first';

    $lang->confirm_submit = 'Are you sure to submit?';
    $lang->confirm_logout = 'Are you sure to logout?';
    $lang->confirm_vote = 'Are you sure to recommend?';
    $lang->confirm_delete = 'Are you sure to delete?';
    $lang->confirm_move = 'Are you sure to move?';
    $lang->confirm_reset = 'Are you sure to reset?';
    $lang->confirm_leave = 'Are you sure to leave?';

    $lang->column_type = 'Column Type';
    $lang->column_type_list['text'] = 'one-line text';
    $lang->column_type_list['homepage'] = 'url';
    $lang->column_type_list['email_address'] = 'email';
    $lang->column_type_list['tel'] = 'phone number';
    $lang->column_type_list['textarea'] = 'multi-line textarea';
    $lang->column_type_list['checkbox'] = 'checkbox (multiple selection)';
    $lang->column_type_list['select'] = 'select box (single selection)';
    $lang->column_type_list['kr_zip'] = 'zip code (Korean)';
    $lang->column_type_list['date'] = 'date (yyyy/mm/dd)';
    //$lang->column_type_list['jp_zip'] = 'zip code (Japanese)';
    $lang->column_name = 'Column Name';
    $lang->column_title = 'Column Title';
    $lang->default_value = 'Default Value';
    $lang->is_active = 'Active';
    $lang->is_required = 'Required Field';

    // Alert messages for Javascript using by XML filter
    $lang->filter->isnull = 'Please input a value for %s';
    $lang->filter->outofrange = 'Please align the text length of %s';
    $lang->filter->equalto = "%s's value is invalid";
    $lang->filter->invalid_email = "%s's format is invalid. ex) zbxe@zeroboard.com";
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "%s's format is invalid.\\nAll values should consist of alphabets, numbers or underscore(_) and the first letter should be English alphabet";
    $lang->filter->invalid_homepage = "%s's format is invalid. ex) http://www.zeroboard.com";
    $lang->filter->invalid_korean = "%s's format is invalid. Please input only Korean";
    $lang->filter->invalid_korean_number = "%s's format is invalid. Please input Korean or numbers";
    $lang->filter->invalid_alpha = "%s's format is invalid. Please input only alphabets";
    $lang->filter->invalid_alpha_number = "%s's format is invalid. Please input alphabets or numbers";
    $lang->filter->invalid_number = "%s's format is invalid. Please input only numbers";
?>
